Index: rtp.c
===================================================================
RCS file: /usr/cvsroot/asterisk/rtp.c,v
retrieving revision 1.9
diff -u -r1.9 rtp.c
--- rtp.c	18 Apr 2003 14:39:26 -0000	1.9
+++ rtp.c	23 Apr 2003 08:57:10 -0000
@@ -526,7 +526,7 @@
   return "";
 }
 
-struct ast_rtp *ast_rtp_new(struct sched_context *sched, struct io_context *io)
+struct ast_rtp *ast_rtp_new(struct sched_context *sched, struct io_context *io, int rtp_min_port, int rtp_max_port)
 {
 	struct ast_rtp *rtp;
 	int x;
@@ -547,9 +547,25 @@
 	}
 	flags = fcntl(rtp->s, F_GETFL);
 	fcntl(rtp->s, F_SETFL, flags | O_NONBLOCK);
+
+        if ( rtp_min_port <= AST_RTP_MIN_PORT) {
+        	ast_log(LOG_WARNING, "RTP minimum port <= %i, fixing to %i\n",AST_RTP_MIN_PORT-1, AST_RTP_MIN_PORT);
+                rtp_min_port = AST_RTP_MIN_PORT;
+	}
+	if ( rtp_max_port > AST_RTP_MAX_PORT) {
+		ast_log(LOG_WARNING, "RTP maximum port > %i, fixing to %i\n",AST_RTP_MAX_PORT,AST_RTP_MAX_PORT);
+		rtp_max_port = AST_RTP_MAX_PORT;
+	}
+	if ( rtp_min_port >= rtp_max_port) {
+		ast_log(LOG_WARNING, "RTP minimum port >= maximum port, fixing to %i and %i\n",AST_RTP_MIN_PORT,AST_RTP_MAX_PORT);
+		rtp_min_port = AST_RTP_MIN_PORT;
+                rtp_max_port = AST_RTP_MAX_PORT;
+	}
+
 	for (;;) {
 		/* Find us a place */
-		x = (rand() % (65000-1025)) + 1025;
+                x = (rand() % (rtp_max_port-rtp_min_port)) + rtp_min_port;
+
 		/* Must be an even port number by RTP spec */
 		x = x & ~1;
 		rtp->us.sin_port = htons(x);
Index: channels/chan_mgcp.c
===================================================================
RCS file: /usr/cvsroot/asterisk/channels/chan_mgcp.c,v
retrieving revision 1.7
diff -u -r1.7 chan_mgcp.c
--- channels/chan_mgcp.c	14 Apr 2003 20:48:30 -0000	1.7
+++ channels/chan_mgcp.c	23 Apr 2003 08:57:11 -0000
@@ -77,6 +77,8 @@
 static char ourhost[256];
 static struct in_addr __ourip;
 static int ourport;
+static int rtp_min_port = AST_RTP_MIN_PORT;
+static int rtp_max_port = AST_RTP_MAX_PORT;
 
 static int mgcpdebug = 0;
 
@@ -1370,7 +1372,7 @@
 {
 		ast_pthread_mutex_lock(&p->lock);
 		/* Allocate the RTP now */
-		p->rtp = ast_rtp_new(NULL, NULL);
+		p->rtp = ast_rtp_new(NULL, NULL,rtp_min_port, rtp_max_port);
 		if (p->rtp && p->owner)
 			p->owner->fds[0] = ast_rtp_fd(p->rtp);
 		if (p->rtp)
@@ -1902,7 +1904,9 @@
 			} else {
 				ast_log(LOG_WARNING, "Invalid port number '%s' at line %d of %s\n", v->value, v->lineno, config);
 			}
-		}
+                } else if (!strcasecmp(v->name, "rtpports")) {
+                        sscanf(v->value, "%i-%i", &rtp_min_port,&rtp_max_port);
+                }
 		v = v->next;
 	}
 	
Index: channels/chan_sip.c
===================================================================
RCS file: /usr/cvsroot/asterisk/channels/chan_sip.c,v
retrieving revision 1.87
diff -u -r1.87 chan_sip.c
--- channels/chan_sip.c	21 Apr 2003 16:49:41 -0000	1.87
+++ channels/chan_sip.c	23 Apr 2003 08:57:13 -0000
@@ -111,6 +111,8 @@
 static char ourhost[256];
 static struct in_addr __ourip;
 static int ourport;
+static int rtp_min_port = AST_RTP_MIN_PORT;
+static int rtp_max_port = AST_RTP_MAX_PORT;
 
 static int sipdebug = 0;
 
@@ -1322,7 +1324,7 @@
 	p->initid = -1;
 	p->autokillid = -1;
 	p->stateid = -1;
-	p->rtp = ast_rtp_new(NULL, NULL);
+	p->rtp = ast_rtp_new(NULL, NULL, rtp_min_port, rtp_max_port); 
 	p->branch = rand();	
 	p->tag = rand();
 	
@@ -5176,7 +5178,12 @@
 			} else {
 				ast_log(LOG_WARNING, "Invalid port number '%s' at line %d of %s\n", v->value, v->lineno, config);
 			}
-		} //else if (strcasecmp(v->name,"type"))
+		} else if (!strcasecmp(v->name, "rtpports")) {
+			sscanf(v->value, "%i-%i", &rtp_min_port,&rtp_max_port);
+		} 
+
+
+	//else if (strcasecmp(v->name,"type"))
 		//	ast_log(LOG_WARNING, "Ignoring %s\n", v->name);
 		 v = v->next;
 	}
Index: include/asterisk/rtp.h
===================================================================
RCS file: /usr/cvsroot/asterisk/include/asterisk/rtp.h,v
retrieving revision 1.2
diff -u -r1.2 rtp.h
--- include/asterisk/rtp.h	20 Mar 2003 22:01:53 -0000	1.2
+++ include/asterisk/rtp.h	23 Apr 2003 08:57:14 -0000
@@ -33,6 +33,10 @@
 /*! Maximum RTP-specific code */
 #define AST_RTP_MAX             AST_RTP_CN
 
+
+#define AST_RTP_MIN_PORT 1025
+#define AST_RTP_MAX_PORT 65000
+
 struct ast_rtp_protocol {
 	struct ast_rtp *(*get_rtp_info)(struct ast_channel *chan);				/* Get RTP struct, or NULL if unwilling to transfer */
 	int (*set_rtp_peer)(struct ast_channel *chan, struct ast_rtp *peer);	/* Set RTP peer */
@@ -45,7 +49,7 @@
 
 typedef int (*ast_rtp_callback)(struct ast_rtp *rtp, struct ast_frame *f, void *data);
 
-struct ast_rtp *ast_rtp_new(struct sched_context *sched, struct io_context *io);
+struct ast_rtp *ast_rtp_new(struct sched_context *sched, struct io_context *io, int rtp_min_port, int rtp_max_port);
 
 void ast_rtp_set_peer(struct ast_rtp *rtp, struct sockaddr_in *them);
 
